==> dword-1.0.3.tgz: package/modules/jshint/README.md <==
# JSHint, A Static Code Analysis Tool for JavaScript

\[ [Use it online](http://jshint.com/) • [About](http://jshint.com/about/) •
[Docs](http://jshint.com/docs/) • [FAQ](http://jshint.com/docs/faq) •
[Install](http://jshint.com/install/) • [Hack](http://jshint.com/hack/) •
[Blog](http://jshint.com/blog/) • [Twitter](https://twitter.com/jshint/) \]

[![NPM version](https://badge.fury.io/js/jshint.svg)](http://badge.fury.io/js/jshint)
[![Build Status](https://travis-ci.org/jshint/jshint.svg?branch=master)](https://travis-ci.org/jshint/jshint)
[![Windows Build status](https://ci.appveyor.com/api/projects/status/v8w3phg5rkhhsx44/branch/master?svg=true)](https://ci.appveyor.com/project/jshint/jshint)
[![Dependency Status](https://david-dm.org/jshint/jshint.svg)](https://david-dm.org/jshint/jshint)
[![devDependency Status](https://david-dm.org/jshint/jshint/dev-status.svg)](https://david-dm.org/jshint/jshint#info=devDependencies)  
[![Code Coverage](https://img.shields.io/coveralls/jshint/jshint/master.svg)](https://coveralls.io/r/jshint/jshint?branch=master)

JSHint is a community-driven tool to detect errors and potential problems
in JavaScript code. It is very flexible so you can easily adjust it to your
particular coding guidelines and the environment you expect your code to
execute in.

## Reporting a bug

To report a bug simply create a
[new GitHub Issue](https://github.com/jshint/jshint/issues/new) and describe
your problem or suggestion. We welcome all kind of feedback regarding
JSHint including but not limited to:

 * When JSHint doesn't work as expected
 * When JSHint complains about valid JavaScript code that works in all browsers
 * When you simply want a new option or feature

Before reporting a bug look around to see if there are any open or closed tickets
that cover your issue. And remember the wisdom: pull request > bug report > tweet.

## Issue Priority

- *P1:* Something is throwing exceptions; broken JSHint backward compatibility.
- *P2:* Something is not being parsed correctly.
- *P3:* Features that the core team will work on once P2s and P1s are done.
- *P4:* Patches welcome; The request is good, but low priority.


## License

JSHint is distributed under the MIT License. One file and one file only
(src/stable/jshint.js) is distributed under the slightly modified MIT License.


## Thank you!

We really appreciate all kind of feedback and contributions. Thanks for using and supporting JSHint!

==> dword-1.3.12.tgz: package/modules/jshint/README.md <==
# JSHint, A Static Code Analysis Tool for JavaScript

\[ [Use it online](http://jshint.com/) • [About](http://jshint.com/about/) •
[Docs](http://jshint.com/docs/) • [FAQ](http://jshint.com/docs/faq) •
[Install](http://jshint.com/install/) • [Hack](http://jshint.com/hack/) •
[Blog](http://jshint.com/blog/) • [Twitter](https://twitter.com/jshint/) \]

[![NPM version](https://img.shields.io/npm/v/jshint.svg?style=flat)](https://www.npmjs.com/package/jshint)
[![Linux Build Status](https://img.shields.io/travis/jshint/jshint/master.svg?style=flat&label=Linux%20build)](https://travis-ci.org/jshint/jshint)
[![Windows Build status](https://img.shields.io/appveyor/ci/jshint/jshint/master.svg?style=flat&label=Windows%20build)](https://ci.appveyor.com/project/jshint/jshint/branch/master)
[![Dependency Status](https://img.shields.io/david/jshint/jshint.svg?style=flat)](https://david-dm.org/jshint/jshint)
[![devDependency Status](https://img.shields.io/david/dev/jshint/jshint.svg?style=flat)](https://david-dm.org/jshint/jshint#info=devDependencies)
[![Coverage Status](https://img.shields.io/coveralls/jshint/jshint.svg?style=flat)](https://coveralls.io/r/jshint/jshint?branch=master)

JSHint is a community-driven tool to detect errors and potential problems
in JavaScript code. It is very flexible so you can easily adjust it to your
particular coding guidelines and the environment you expect your code to
execute in.

## Reporting a bug

To report a bug simply create a
[new GitHub Issue](https://github.com/jshint/jshint/issues/new) and describe
your problem or suggestion. We welcome all kind of feedback regarding
JSHint including but not limited to:

 * When JSHint doesn't work as expected
 * When JSHint complains about valid JavaScript code that works in all browsers
 * When you simply want a new option or feature

Before reporting a bug look around to see if there are any open or closed tickets
that cover your issue. And remember the wisdom: pull request > bug report > tweet.

## Issue Priority

- *P1:* Something is throwing exceptions; broken JSHint backward compatibility.
- *P2:* Something is not being parsed correctly.
- *P3:* Features that the core team will work on once P2s and P1s are done.
- *P4:* Patches welcome; The request is good, but low priority.


## License

JSHint is distributed under the MIT License. One file and one file only
(src/stable/jshint.js) is distributed under the slightly modified MIT License.

## The JSHint Team

JSHint is maintained by [Rick Waldron](https://github.com/rwaldron/), [Caitlin
Potter](https://github.com/caitp/), [Mike
Sherov](https://github.com/mikesherov/), and [Mike
Pennisi](https://github.com/jugglinmike/).

## Thank you!

We really appreciate all kind of feedback and contributions. Thanks for using and supporting JSHint!
